@@ -1,7 +1,7 @@
 
 ;;;### (autoloads nil "_pkg" "auctex/_pkg.el")
 
-(package-provide 'auctex :version 2017.0724 :author-version "release_11_91" :type 'regular)
+(package-provide 'auctex :version 2017.1203 :author-version "release_11_92" :type 'regular)
 
 ;;;***
 
@@ -133,7 +133,7 @@ Special commands:
 
 Entering `plain-tex-mode' calls the value of `text-mode-hook',
 then the value of `TeX-mode-hook', and then the value
-of plain-TeX-mode-hook." t nil)
+of `plain-TeX-mode-hook'." t nil)
 
 (autoload 'ams-tex-mode "plain-tex" "\
 Major mode in AUCTeX for editing AmS-TeX files.
@@ -142,7 +142,7 @@ See info under AUCTeX for documentation.
 Special commands:
 \\{AmSTeX-mode-map}
 
-Entering AmS-tex-mode calls the value of `text-mode-hook',
+Entering `ams-tex-mode' calls the value of `text-mode-hook',
 then the value of `TeX-mode-hook', and then the value
 of `AmS-TeX-mode-hook'." t nil)
 
@@ -277,7 +277,7 @@ Limit searched to BOUND." nil nil)
 ;;;***
 ;;; tex-site.el - Site specific variables.  Don't edit.
 
-;; Copyright (C) 2005, 2013, 2016 Free Software Foundation, Inc.
+;; Copyright (C) 2005, 2013, 2016-2017 Free Software Foundation, Inc.
 ;;
 ;; completely rewritten.
 
@@ -316,7 +316,14 @@ Limit searched to BOUND." nil nil)
 ;;; Code:
 
 (if (< emacs-major-version 21)
-    (error "AUCTeX requires Emacs 21 or later"))
+    (error "AUCTeX requires Emacs 21 or later")) ;FIXME: Really?
+
+(unless (or (fboundp 'TeX-modes-set)     ;Avoid inf-looping.
+            (fboundp 'TeX-tex-mode))     ;auctex-autoloads is not loaded.
+  ;; Try and support the case where someone loads tex-site.el or
+  ;; auctex.el directly, in the old way.
+  (provide 'tex-site)        ;Avoid (re)loading tex-site from auctex-autoloads.
+  (load "auctex-autoloads" 'noerror 'nomessage))
 
 ;; Define here in order for `M-x customize-group <RET> AUCTeX <RET>'
 ;; to work if the main AUCTeX files are not loaded yet.
@@ -427,11 +434,11 @@ set it with `TeX-modes-set'."
 		       `(TeX-modes-set ',var ,var t))
 		     (setq list (cdr list)))))) )
 
-(defconst AUCTeX-version "release_11_91"
+(defconst AUCTeX-version "release_11_92"
     "AUCTeX version.
 If not a regular release, the date of the last change.")
 
-(defconst AUCTeX-date "2017-07-24"
+(defconst AUCTeX-date "2017-12-03"
   "AUCTeX release date using the ISO 8601 format, yyyy-mm-dd.")
 
 ;; Store bibitems when saving a BibTeX buffer
